==> nextcloud-28.0.9.tgz: nextcloud/apps/files_reminders/l10n/ru.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Напоминания о файлах",
    "Reminder for {name}" : "Напоминание для {name}",
    "View file" : "Просмотреть файл",
    "View folder" : "Просмотреть папку",
    "Set file reminders" : "Установить напоминания о файлах",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Напоминания о файлах**\n\nУстановить напоминания о файлах.",
    "Please choose a valid date & time" : "Пожалуйста, выберите правильную дату и время",
    "Cancel" : "Отмена",
    "Clear reminder" : "Очистить напоминание",
    "Set reminder" : "Установить напоминание",
    "Set reminder at custom date & time" : "Установить напоминание на индивидуальную дату и время",
    "Reminder set for \"{fileName}\"" : "Напоминание для \"{fileName}\"",
    "Failed to set reminder" : "Не удалось установить напоминание",
    "Failed to clear reminder" : "Не удалось удалить напоминание",
    "Set custom reminder" : "Установить особое напоминание",
    "Later today" : "Позже сегодня",
    "Set reminder for later today" : "Установить напоминание позднее сегодня",
    "Tomorrow" : "Завтра",
    "Set reminder for tomorrow" : "Установить напоминание на завтра",
    "This weekend" : "Эта неделя",
    "Set reminder for this weekend" : "Установить напоминание на эти выходные",
    "Next week" : "Следующая неделя",
    "Set reminder for next week" : "Установить напоминание на следующую неделю"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-29.0.10.tgz: nextcloud/apps/files_reminders/l10n/ru.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Напоминания о файлах",
    "Reminder for {name}" : "Напоминание для {name}",
    "View file" : "Просмотреть файл",
    "View folder" : "Просмотреть папку",
    "Set file reminders" : "Установить напоминания о файлах",
    "We will remind you of this file" : "Мы напомним вам об этом файле",
    "Please choose a valid date & time" : "Пожалуйста, выберите правильную дату и время",
    "Cancel" : "Отмена",
    "Clear reminder" : "Очистить напоминание",
    "Set reminder" : "Установить напоминание",
    "Set reminder for \"{fileName}\"" : "Установить напоминание для \"{fileName}\"",
    "Set reminder at custom date & time" : "Установить напоминание на индивидуальную дату и время",
    "Reminder set for \"{fileName}\"" : "Напоминание для \"{fileName}\"",
    "Failed to set reminder" : "Не удалось установить напоминание",
    "Reminder cleared for \"{fileName}\"" : "Напоминание очищено для \"{fileName}\"",
    "Failed to clear reminder" : "Не удалось удалить напоминание",
    "Reminder set" : "Установить напоминание",
    "Set custom reminder" : "Установить особое напоминание",
    "Later today" : "Позже сегодня",
    "Set reminder for later today" : "Установить напоминание позднее сегодня",
    "Tomorrow" : "Завтра",
    "Set reminder for tomorrow" : "Установить напоминание на завтра",
    "This weekend" : "Эта неделя",
    "Set reminder for this weekend" : "Установить напоминание на эти выходные",
    "Next week" : "Следующая неделя",
    "Set reminder for next week" : "Установить напоминание на следующую неделю",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Напоминания о файлах**\n\nУстановить напоминания о файлах."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
